AutoArchive._infrastructure.ui.constants — AutoArchive Developer Manual (ver. 1.2.1)

### Navigation

- index
- modules |
- AutoArchive Developer Manual (ver. 1.2.1) »
- Module code »

# Source code for AutoArchive._infrastructure.ui.constants

    # constants.py
    #
    # Project: AutoArchive
    # License: GNU GPLv3
    #
    # Copyright (C) 2003 - 2014 Róbert Čerňanský

    """:data:`UiMessageKinds` and :data:`VerbosityLevels` enums."""

    __all__ = ["UiMessageKinds", "VerbosityLevels"]

    # {{{ INCLUDES

    from AutoArchive._infrastructure.py_additions import Enum

    # }}} INCLUDES

    # {{{ CONSTANTS

    #: Kinds of user messages.
    UiMessageKinds = Enum(
        "Verbose",
        "Notification",
        "Info",
        "Warning",
        "Error")

    #: Verbosity levels.
    VerbosityLevels = Enum(
        "Quiet",
        "Normal",
        "Verbose")

    # }}} CONSTANTS

### Navigation

- index
- modules |
- AutoArchive Developer Manual (ver. 1.2.1) »
- Module code »